@@ -1,5 +1,5 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: imap.c 487 2007-03-23 16:53:15Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: imap.c 543 2007-04-26 04:06:02Z mikes@u.washington.edu $";
 #endif
 
 /*
@@ -1365,7 +1365,7 @@ pine_sslcertquery(char *reason, char *host, char *cert)
 	gf_link_filter(gf_html2plain,
 		       gf_html2plain_opt(NULL,
 					 ps_global->ttyo->screen_cols, NULL,
-					 &handles, GFHP_LOCAL_HANDLES));
+					 &handles, NULL, GFHP_LOCAL_HANDLES));
 	gf_set_so_readc(&gc, in_store);
 	gf_set_so_writec(&pc, out_store);
 	gf_pipe(gc, pc);
