@@ -23,7 +23,7 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	27 July 1988
- * Last Edited:	27 November 2006
+ * Last Edited:	6 December 2006
  *
  * This original version of this file is
  * Copyright 1988 Stanford University
@@ -37,11 +37,7 @@
 #include <ctype.h>
 #include <stdio.h>
 #include <time.h>
-#include "mail.h"
-#include "osdep.h"
-#include "rfc822.h"
-#include "misc.h"
-#include "utf8.h"
+#include "c-client.h"
 
 
 /* Support for deprecated features in earlier specifications.  Note that this
