@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 1988-2006 University of Washington
+ * Copyright 1988-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	23 February 1992
- * Last Edited:	13 November 2006
+ * Last Edited:	18 April 2007
  */
 
 
@@ -205,8 +205,8 @@ int mh_isvalid (char *name,char *tmp,long synonly)
   }
 				/* see if non-NS name within mh hierarchy */
   else if ((name[0] != '#') && (s = mh_path (tmp)) && (i = strlen (s)) &&
-	   (t = mailboxfile (tmp,name)) && !strncmp (t,s,i) && (tmp[i] == '/') &&
-	   tmp[i+1]) {
+	   (t = mailboxfile (tmp,name)) && !strncmp (t,s,i) &&
+	   (tmp[i] == '/') && tmp[i+1]) {
     sprintf (altname,"#mh%.900s",tmp+i);
 				/* can't do synonly here! */
     ret = mh_isvalid (altname,tmp,NIL);
@@ -241,7 +241,7 @@ int mh_namevalid (char *name)
 
 char *mh_path (char *tmp)
 {
-  char *s,*t,*v;
+  char *s,*t,*v,*r;
   int fd;
   struct stat sbuf;
   if (!mh_profile) {		/* build mh_profile and mh_pathname now */
@@ -252,7 +252,7 @@ char *mh_path (char *tmp)
       close (fd);		/* don't need the file any more */
       t[sbuf.st_size] = '\0';	/* tie it off */
 				/* parse profile file */
-      for (s = strtok (t,"\r\n"); s && *s; s = strtok (NIL,"\r\n")) {
+      for (s = strtok_r (t,"\r\n",&r); s && *s; s = strtok_r (NIL,"\r\n",&r)) {
 				/* found space in line? */
 	if (v = strpbrk (s," \t")) {
 	  *v++ = '\0';		/* tie off, is keyword "Path:"? */
@@ -315,7 +315,7 @@ void *mh_parameters (long function,void *value)
 }
 
 
-/* MX test for directory format internal node
+/* MH test for directory format internal node
  * Accepts: candidate node name
  * Returns: T if internal name, NIL otherwise
  */
@@ -903,7 +903,7 @@ long mh_ping (MAILSTREAM *stream)
 				/* snarf message from Berkeley mailbox */
 	selt = mail_elt (sysibx,i);
 	if (((fd = open (LOCAL->buf,O_WRONLY|O_CREAT|O_EXCL,
-			 (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL)))
+			 (long) mail_parameters (NIL,GET_MBXPROTECTION,NIL)))
 	     >= 0) &&
 	    (s = mail_fetchheader_full (sysibx,i,NIL,&j,FT_INTERNAL)) &&
 	    (write (fd,s,j) == j) &&
@@ -1155,7 +1155,7 @@ long mh_append (MAILSTREAM *stream,char *mailbox,append_t af,void *data)
     mh_file (tmp,mailbox);	/* build file name we will use */
     sprintf (tmp + strlen (tmp),"/%ld",++last);
     if (((fd = open (tmp,O_WRONLY|O_CREAT|O_EXCL,
-		     (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL))) < 0)||
+		     (long)mail_parameters (NIL,GET_MBXPROTECTION,NIL))) < 0)||
 	!(df = fdopen (fd,"ab"))) {
       sprintf (tmp,"Can't open append message: %s",strerror (errno));
       mm_log (tmp,ERROR);
