@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 1988-2006 University of Washington
+ * Copyright 1988-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	20 December 1989
- * Last Edited:	20 December 2006
+ * Last Edited:	18 April 2007
  */
 
 
@@ -61,6 +61,7 @@ typedef struct unix_local {
   unsigned int dirty : 1;	/* disk copy needs updating */
   unsigned int ddirty : 1;	/* double-dirty, ping becomes checkpoint */
   unsigned int pseudo : 1;	/* uses a pseudo message */
+  unsigned int appending : 1;	/* don't mark new messages as old */
   int fd;			/* mailbox file descriptor */
   int ld;			/* lock file descriptor */
   char *lname;			/* lock file name */
@@ -922,8 +923,11 @@ long unix_copy (MAILSTREAM *stream,char *sequence,char *mailbox,long options)
 	 sbuf.st_atime : times.modtime;
   utime (file,&times);		/* set the times */
   unix_unlock (fd,NIL,lock);	/* unlock and close mailbox */
-				/* update last UID if we can */
-  if (!tstream->rdonly) ((UNIXLOCAL *) tstream->local)->dirty = T;
+  if (!tstream->rdonly) {	/* update last UID if we can */
+    UNIXLOCAL * local = (UNIXLOCAL *) tstream->local;
+    local->dirty = T;		/* do a rewrite */
+    local->appending = T;	/* but not at the cost of marking as old */
+  }
   tstream = mail_close (tstream);
 				/* log the error */
   if (!ret) mm_log (LOCAL->buf,ERROR);
@@ -1090,8 +1094,11 @@ long unix_append (MAILSTREAM *stream,char *mailbox,append_t af,void *data)
   flock (fd,LOCK_UN);		/* unlock mailbox (can't use unix_unlock() */
   if (lock && *lock) unlink (lock);
   fclose (df);			/* close mailbox */
-				/* update last UID if we can */
-  if (!tstream->rdonly) ((UNIXLOCAL *) tstream->local)->dirty = T;
+  if (!tstream->rdonly) {	/* update last UID if we can */
+    UNIXLOCAL * local = (UNIXLOCAL *) tstream->local;
+    local->dirty = T;		/* do a rewrite */
+    local->appending = T;	/* but not at the cost of marking as old */
+  }
   tstream = mail_close (tstream);
   mm_nocritical (stream);	/* release critical */
   return ret;
@@ -1189,6 +1196,7 @@ int unix_append_msgs (MAILSTREAM *stream,FILE *sf,FILE *df,SEARCHSET *set)
 	    ((tmp[4] == 'u') || (tmp[4] == 'U')) &&
 	    ((tmp[5] == 's') || (tmp[5] == 'S')) && (tmp[6] == ':') &&
 	    (fputs ("X-Original-",df) == EOF)) return NIL;
+	break;
       case 'X': case 'x':	/* possible X-??? header */
 	if (hdrp && (tmp[1] == '-') &&
 				/* possible X-UID: */
@@ -1223,6 +1231,10 @@ int unix_append_msgs (MAILSTREAM *stream,FILE *sf,FILE *df,SEARCHSET *set)
 	      ((tmp[8] == 'd') || (tmp[8] == 'D')) &&
 	      ((tmp[9] == 's') || (tmp[9] == 'S')) && (tmp[10] == ':'))) &&
 	    (fputs ("X-Original-",df) == EOF)) return NIL;
+	break;
+      case '\n':		/* blank line */
+	hdrp = NIL;
+	break;
       default:			/* nothing to do */
 	break;
       }
@@ -1720,8 +1732,13 @@ int unix_parse (MAILSTREAM *stream,char *lock,int op)
 	  if (i) {		/* got new data? */
 	    VALID (s,t,ti,zn);	/* yes, parse line */
 	    if (!ti) {		/* not a header line, add it to message */
-	      elt->rfc822_size += 
-		k = i + (m = (((i < 2) || s[i - 2] != '\r') ? 1 : 0));
+	      if (s[i - 1] == '\n')
+		elt->rfc822_size += 
+		  k = i + (m = (((i < 2) || s[i - 2] != '\r') ? 1 : 0));
+	      else {		/* file does not end with newline! */
+		elt->rfc822_size += i;
+		k = m = 0;
+	      }
 				/* update current position */
 	      j = LOCAL->filesize + GETPOS (&bs);
 	    }
@@ -1843,7 +1860,8 @@ char *unix_mbxline (MAILSTREAM *stream,STRING *bs,unsigned long *size)
 	bs->cursize -= k;	/* eat that many bytes */
       }
       if (!bs->cursize) SETPOS (bs,GETPOS (bs));
-      if (SIZE (bs)) SNX (bs);	/* skip over newline if one seen */
+				/* read newline at end */
+      if (SIZE (bs)) ret[i++] = SNX (bs);
       ret[i++] = '\n';		/* make sure newline at end */
       ret[i] = '\0';		/* makes debugging easier */
     }
@@ -1908,7 +1926,8 @@ unsigned long unix_xstatus (MAILSTREAM *stream,char *status,MESSAGECACHE *elt,
   *s++ = 'S'; *s++ = 't'; *s++ = 'a'; *s++ = 't'; *s++ = 'u'; *s++ = 's';
   *s++ = ':'; *s++ = ' ';
   if (elt->seen) *s++ = 'R';
-  if (flag) *s++ = 'O';		/* only write O if have a UID */
+				/* only write O if have a UID */
+  if (flag && (!elt->recent || LOCAL->appending)) *s++ = 'O';
   *s++ = '\r'; *s++ = '\n';
   *s++ = 'X'; *s++ = '-'; *s++ = 'S'; *s++ = 't'; *s++ = 'a'; *s++ = 't';
   *s++ = 'u'; *s++ = 's'; *s++ = ':'; *s++ = ' ';
