@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 1988-2006 University of Washington
+ * Copyright 1988-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,7 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	20 December 1989
- * Last Edited:	13 November 2006
+ * Last Edited:	18 April 2007
  */
 
 
@@ -60,6 +60,7 @@ typedef struct unix_local {
   unsigned int dirty : 1;	/* disk copy needs updating */
   unsigned int ddirty : 1;	/* double-dirty, ping becomes checkpoint */
   unsigned int pseudo : 1;	/* uses a pseudo message */
+  unsigned int appending : 1;	/* don't mark new messages as old */
   int fd;			/* mailbox file descriptor */
   int ld;			/* lock file descriptor */
   char *lname;			/* lock file name */
@@ -337,7 +338,7 @@ long unix_create (MAILSTREAM *stream,char *mailbox)
     if (((s = strrchr (s,'/')) && !s[1]) ||
 	mail_parameters (NIL,GET_USERHASNOLIFE,NIL)) ret = T;
     else if ((fd = open (mbx,O_WRONLY,
-		    (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL))) < 0) {
+		    (long) mail_parameters (NIL,GET_MBXPROTECTION,NIL))) < 0) {
       sprintf (tmp,"Can't reopen mailbox node %.80s: %s",mbx,strerror (errno));
       MM_LOG (tmp,ERROR);
       unlink (mbx);		/* delete the file */
@@ -410,7 +411,7 @@ long unix_rename (MAILSTREAM *stream,char *old,char *newname)
 
   else {
     if ((fd = unix_lock (file,O_RDWR,
-			 (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
+			 (long) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
 			 &lockx,LOCK_EX)) < 0)
       sprintf (tmp,"Can't lock mailbox %.80s: %s",old,strerror (errno));
     else {
@@ -511,7 +512,7 @@ MAILSTREAM *unix_open (MAILSTREAM *stream)
       LOCAL->ld = fd;		/* note lock's fd and name */
       LOCAL->lname = cpystr (tmp);
 				/* make sure mode OK (don't use fchmod()) */
-      chmod (LOCAL->lname,(int) mail_parameters (NIL,GET_LOCKPROTECTION,NIL));
+      chmod (LOCAL->lname,(long) mail_parameters (NIL,GET_LOCKPROTECTION,NIL));
       if (stream->silent) i = 0;/* silent streams won't accept KOD */
       else {			/* note our PID in the lock */
 	sprintf (tmp,"%d",getpid ());
@@ -647,7 +648,7 @@ char *unix_header (MAILSTREAM *stream,unsigned long msgno,
     fs_give ((void **) &s);	/* free readin buffer */
   }
   *length = mail_filter (LOCAL->buf,*length,unix_hlines,FT_NOT);
-  return LOCAL->buf;		/* return processed copy */
+  return (char *) LOCAL->buf;	/* return processed copy */
 }
 
 /* UNIX mail fetch message text
@@ -708,7 +709,7 @@ char *unix_text_work (MAILSTREAM *stream,MESSAGECACHE *elt,
       if ((*t != '\r') || (t[1] != '\n')) *s++ = *t;
 				/* adjust length */
     LOCAL->buf[*length = s - LOCAL->buf - 1] = '\0';
-    return LOCAL->buf;
+    return (char *) LOCAL->buf;
   }
 
 				/* have it cached already? */
@@ -791,7 +792,7 @@ long unix_ping (MAILSTREAM *stream)
 	reparse = (sbuf.st_size != LOCAL->filesize);
       }
 				/* parse if mailbox changed */
-      if ((LOCAL->ddirty || reparse) && unix_parse (stream,&lock,LOCK_SH)) {
+      if ((LOCAL->ddirty || reparse) && unix_parse (stream,&lock,LOCK_EX)) {
 				/* force checkpoint if double-dirty */
 	if (LOCAL->ddirty) unix_rewrite (stream,NIL,&lock,NIL);
 				/* unlock mailbox */
@@ -935,7 +936,7 @@ long unix_copy (MAILSTREAM *stream,char *sequence,char *mailbox,long options)
   LOCAL->buf[0] = '\0';
   MM_CRITICAL (stream);		/* go critical */
   if ((fd = unix_lock (dummy_file (file,mailbox),O_WRONLY|O_APPEND,
-		       (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
+		       (long) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
 		       &lock,LOCK_EX)) < 0) {
     MM_NOCRITICAL (stream);	/* done with critical */
     sprintf (LOCAL->buf,"Can't open destination mailbox: %s",strerror (errno));
@@ -992,8 +993,11 @@ long unix_copy (MAILSTREAM *stream,char *sequence,char *mailbox,long options)
 	 sbuf.st_atime : tp[1];
   utime (file,tp);		/* set the times */
   unix_unlock (fd,NIL,&lock);	/* unlock and close mailbox */
-				/* update last UID if we can */
-  if (!tstream->rdonly) ((UNIXLOCAL *) tstream->local)->dirty = T;
+  if (!tstream->rdonly) {	/* update last UID if we can */
+    UNIXLOCAL *local = (UNIXLOCAL *) tstream->local;
+    local->dirty = T;		/* do a rewrite */
+    local->appending = T;	/* but not at the cost of marking as old */
+  }
   tstream = mail_close (tstream);
 				/* log the error */
   if (!ret) MM_LOG (LOCAL->buf,ERROR);
@@ -1124,7 +1128,7 @@ long unix_append (MAILSTREAM *stream,char *mailbox,append_t af,void *data)
     return NIL;
   }
   if (((fd = unix_lock (dummy_file (file,mailbox),O_WRONLY|O_APPEND,
-		       (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
+		       (long) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
 			&lock,LOCK_EX)) < 0) ||
       !(df = fdopen (fd,"ab"))) {
     MM_NOCRITICAL (stream);	/* done with critical */
@@ -1158,8 +1162,11 @@ long unix_append (MAILSTREAM *stream,char *mailbox,append_t af,void *data)
   else mail_free_searchset (&dst);
   unix_unlock (fd,NIL,&lock);	/* unlock and close mailbox */
   fclose (df);			/* note that unix_unlock() released the fd */
-				/* update last UID if we can */
-  if (!tstream->rdonly) ((UNIXLOCAL *) tstream->local)->dirty = T;
+  if (!tstream->rdonly) {	/* update last UID if we can */
+    UNIXLOCAL *local = (UNIXLOCAL *) tstream->local;
+    local->dirty = T;		/* do a rewrite */
+    local->appending = T;	/* but not at the cost of marking as old */
+  }
   tstream = mail_close (tstream);
   MM_NOCRITICAL (stream);	/* release critical */
   return ret;
@@ -1259,6 +1266,7 @@ int unix_append_msgs (MAILSTREAM *stream,FILE *sf,FILE *df,SEARCHSET *set)
 	    ((tmp[4] == 'u') || (tmp[4] == 'U')) &&
 	    ((tmp[5] == 's') || (tmp[5] == 'S')) && (tmp[6] == ':') &&
 	    (fputs ("X-Original-",df) == EOF)) return NIL;
+	break;
       case 'X': case 'x':	/* possible X-??? header */
 	if (hdrp && (tmp[1] == '-') &&
 				/* possible X-UID: */
@@ -1293,6 +1301,9 @@ int unix_append_msgs (MAILSTREAM *stream,FILE *sf,FILE *df,SEARCHSET *set)
 	      ((tmp[8] == 'd') || (tmp[8] == 'D')) &&
 	      ((tmp[9] == 's') || (tmp[9] == 'S')) && (tmp[10] == ':'))) &&
 	    (fputs ("X-Original-",df) == EOF)) return NIL;
+      case '\n':		/* blank line */
+	hdrp = NIL;
+	break;
       default:			/* nothing to do */
 	break;
       }
@@ -1437,7 +1448,7 @@ int unix_parse (MAILSTREAM *stream,DOTLOCK *lock,int op)
   MM_CRITICAL (stream);		/* open and lock mailbox (shared OK) */
   if ((LOCAL->fd = unix_lock (stream->mailbox,(LOCAL->ld >= 0) ?
 			      O_RDWR : O_RDONLY,
-			      (int) mail_parameters(NIL,GET_MBXPROTECTION,NIL),
+			      (long)mail_parameters(NIL,GET_MBXPROTECTION,NIL),
 			      lock,op)) < 0) {
     sprintf (tmp,"Mailbox open failed, aborted: %s",strerror (errno));
     MM_LOG (tmp,ERROR);
@@ -1775,8 +1786,13 @@ int unix_parse (MAILSTREAM *stream,DOTLOCK *lock,int op)
 	  if (i) {		/* got new data? */
 	    VALID (s,t,ti,zn);	/* yes, parse line */
 	    if (!ti) {		/* not a header line, add it to message */
-	      elt->rfc822_size += 
-		k = i + (m = (((i < 2) || s[i - 2] != '\r') ? 1 : 0));
+	      if (s[i - 1] == '\n')
+		elt->rfc822_size += 
+		  k = i + (m = (((i < 2) || s[i - 2] != '\r') ? 1 : 0));
+	      else {		/* file does not end with newline! */
+		elt->rfc822_size += i;
+		k = m = 0;
+	      }
 				/* update current position */
 	      j = LOCAL->filesize + GETPOS (&bs);
 	    }
@@ -1901,8 +1917,8 @@ char *unix_mbxline (MAILSTREAM *stream,STRING *bs,unsigned long *size)
 	bs->cursize -= k;	/* eat that many bytes */
       }
       if (!bs->cursize) SETPOS (bs,GETPOS (bs));
-      if (SIZE (bs)) SNX (bs);	/* skip over newline if one seen */
-      ret[i++] = '\n';		/* make sure newline at end */
+				/* read newline at end */
+      if (SIZE (bs)) ret[i++] = SNX (bs);
       ret[i] = '\0';		/* makes debugging easier */
     }
     else {			/* this is easy */
@@ -1983,7 +1999,8 @@ unsigned long unix_xstatus (MAILSTREAM *stream,char *status,MESSAGECACHE *elt,
   *s++ = 'S'; *s++ = 't'; *s++ = 'a'; *s++ = 't'; *s++ = 'u'; *s++ = 's';
   *s++ = ':'; *s++ = ' ';
   if (elt->seen) *s++ = 'R';
-  if (flag) *s++ = 'O';		/* only write O if have a UID */
+				/* only write O if have a UID */
+  if (flag && (!elt->recent || !LOCAL->appending)) *s++ = 'O';
   *s++ = '\n';
   *s++ = 'X'; *s++ = '-'; *s++ = 'S'; *s++ = 't'; *s++ = 'a'; *s++ = 't';
   *s++ = 'u'; *s++ = 's'; *s++ = ':'; *s++ = ' ';
@@ -2205,7 +2222,7 @@ long unix_rewrite (MAILSTREAM *stream,unsigned long *nexp,DOTLOCK *lock,
     if (!utime (stream->mailbox,tp)) LOCAL->filetime = tp[1];
     close (LOCAL->fd);		/* close and reopen file */
     if ((LOCAL->fd = open (stream->mailbox,O_RDWR,
-			   (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL)))
+			   (long) mail_parameters (NIL,GET_MBXPROTECTION,NIL)))
 	< 0) {
       sprintf (LOCAL->buf,"Mailbox open failed, aborted: %s",strerror (errno));
       MM_LOG (LOCAL->buf,ERROR);
@@ -2548,7 +2565,7 @@ long mbox_ping (MAILSTREAM *stream)
       !stat (sysinbox (),&sbuf) && sbuf.st_size) {
 				/* yes, open and lock sysinbox */
     if ((sfd = unix_lock (sysinbox (),O_RDWR,
-			  (int) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
+			  (long) mail_parameters (NIL,GET_MBXPROTECTION,NIL),
 			  &lockx,LOCK_EX)) >= 0) {
 				/* locked sysinbox in good format? */
       if (fstat (sfd,&sbuf) || !(size = sbuf.st_size) ||
