@@ -1,5 +1,5 @@
 /*
- * $Id: ebind.h 404 2007-01-30 18:54:06Z hubert@u.washington.edu $
+ * $Id: ebind.h 480 2007-03-09 22:34:47Z hubert@u.washington.edu $
  *
  * ========================================================================
  * Copyright 2006 University of Washington
@@ -92,11 +92,10 @@ KEYTAB  keytab[NBINDS] = {
 	{CTRL|'@',		forwword},
 	{CTRL|'^',		setmark},
 	{CTRL|'_',		alt_editor},
-#ifdef _WINDOWS
 	{CTRL|KEY_LEFT, backword},
+	{CTRL|KEY_RIGHT,forwword},
 	{CTRL|KEY_HOME,	gotobob},
 	{CTRL|KEY_END,	gotoeob},
-#endif
 	{0x7F,			backdel},
 	{0,			NULL}
 };
@@ -151,11 +150,10 @@ KEYTAB  pkeytab[NBINDS] = {
 #endif
 	{CTRL|'@',		forwword},
 	{CTRL|'^',		setmark},
-#ifdef _WINDOWS
 	{CTRL|KEY_LEFT, backword},
+	{CTRL|KEY_RIGHT,forwword},
 	{CTRL|KEY_HOME,	gotobob},
 	{CTRL|KEY_END,	gotoeob},
-#endif
 	{0x7F,			backdel},
 	{0,			NULL}
 };
