@@ -1,8 +1,8 @@
 /*
- * $Id: ablookup.h 216 2006-11-02 21:23:08Z hubert@u.washington.edu $
+ * $Id: ablookup.h 406 2007-01-31 00:36:05Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2006 University of Washington
+ * Copyright 2006-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,6 +23,9 @@
 #include "../pith/bldaddr.h"
 
 
+#define ANC_AFTERCOMMA   0x1
+
+
 /* exported protoypes */
 char          *get_nickname_from_addr(ADDRESS *, char *, size_t);
 char          *get_fcc_from_addr(ADDRESS *, char *, size_t);
@@ -33,6 +36,7 @@ int            address_is_us(ADDRESS *, struct pine *);
 int            address_is_same(ADDRESS *, ADDRESS *);
 int            abes_are_equal(AdrBk_Entry *, AdrBk_Entry *);
 char          *addr_lookup(char *, int *, int);
+int            adrbk_nick_complete(char *, char **, unsigned);
 AdrBk_Entry   *adrbk_lookup_with_opens_by_nick(char *, int, int *, int);
 AdrBk_Entry   *address_to_abe(ADDRESS *);
 
